@@ -11,13 +11,12 @@ class Archiver:
     def __init__(self, args):
         """Init."""
         self.retry = args.retry
-        self.UA = 'Mozilla/5.0 (Windows NT 5.1; rv:40.0) '\
-                  'Gecko/20100101 Firefox/40.0'
+        self.UA = "Mozilla/5.0 (Windows NT 5.1; rv:40.0) " "Gecko/20100101 Firefox/40.0"
 
     def archive(self, url):
         """Archive link."""
         wp = waybackpy.Url(url, self.UA)
-        for _ in range(self.retry+1):
+        for _ in range(self.retry + 1):
             if not self._try_savepagenow(wp):
                 continue
             else:
